Learn R Programming

dimRed (version 0.0.3)

maximize_correlation,dimRedResult-method: Maximize Correlation with the Axes

Description

Rotates the data in such a way that the correlation with the first naxes axes is maximized.

Usage

"maximize_correlation"(object, naxes = ncol(object@data@data), cor_method = "pearson")

Arguments

object
A dimRedResult object
naxes
the number of axes to optimize for.
cor_method
which correlation method to use

Details

Methods that do not use eigenvector decomposition, like t-SNE often do not align the data with axes according to the correlation of variables with the data. maximize_correlation uses the optimx package to rotate the data in such a way that the original variables have maximum correlation with the embedding axes.