Usage
plot(x, y, ...)
"plot"(x, type = "pairs", vars = seq_len(ncol(x@data)), col = seq_len(min(3, ncol(x@meta))), ...)
"plot"(x, type = "pairs", vars = seq_len(ncol(x@data@data)), col = seq_len(min(3, ncol(x@data@meta))), ...)
Arguments
x
dimRedResult/dimRedData class, e.g. output of
embedded/loadDataSet
...
handed over to the underlying plotting function.
type
plot type, one of c("pairs", "parallel", "2vars",
"3vars", "3varsrgl")
vars
the axes of the embedding to use for plotting
col
the columns of the meta slot to use for coloring, can be
referenced as the column names or number of x@data