Learn R Programming

dimRed (version 0.0.3)

plot_R_NX: plot_R_NX

Description

Plot the R_NX curve for different embeddings. Takes a list of dimRedResult objects as input. Also the Area under the curve values are computed for logarithmic K (AUC_lnK) and appear in the legend.

Usage

plot_R_NX(x)

Arguments

x
a list of dimRedResult objects. The names of the list will appear in the legend with the AUC_lnK value.

Value

A ggplot object, the design can be changed by appending theme(...)

Examples

Run this code

## define which methods to apply
embed_methods <- c("Isomap", "PCA")
## load test data set
data_set <- loadDataSet("3D S Curve", n = 1000)
## apply dimensionality reduction
data_emb <- lapply(embed_methods, function(x) embed(data_set, x))
names(data_emb) <- embed_methods
## plot the R_NX curves:
plot_R_NX(data_emb) +
    ggplot2::theme(legend.title = ggplot2::element_blank(),
                   legend.position = c(0.5, 0.1),
                   legend.justification = c(0.5, 0.1))

Run the code above in your browser using DataLab