Learn R Programming

dimRed (version 0.0.3)

total_correlation,dimRedResult-method: Method total_correlation

Description

Calculate the total correlation of the variables with the axes to assess the quality of a dimensionality reduction.

Usage

"total_correlation"(object, naxes = ndims(object), cor_method = "pearson", is.rotated = FALSE)

Arguments

object
of class dimRedResult
naxes
the number of axes to use for optimization.
cor_method
the correlation method to use.
is.rotated
if FALSE the object is rotated.

See Also

Other Quality scores for dimensionality reduction: AUC_lnK_R_NX,dimRedResult-method, LCMC,dimRedResult-method, Q_NX,dimRedResult-method, Q_global,dimRedResult-method, Q_local,dimRedResult-method, R_NX,dimRedResult-method, cophenetic_correlation,dimRedResult-method, distance_correlation,dimRedResult-method, mean_R_NX,dimRedResult-method, quality,dimRedResult-method, reconstruction_rmse,dimRedResult-method