Learn R Programming

dimRed (version 0.0.3)

dimRedMethodList: dimRedMethodList

Description

Get the names of all methods for dimensionality reduction.

Usage

dimRedMethodList()

Arguments

Value

a character vector with the names of classes that inherit from dimRedMethod.

Details

Returns the name of all classes that inherit from dimRedMethod-class to use with embed.

Examples

Run this code
dimRedMethodList()

Run the code above in your browser using DataLab